| plot.store | R Documentation |
Plots coefficients for the various trait-state combinations of a store fit.
## S3 method for class 'store'
plot(
x,
type = c("coef", "fitted"),
bubble = FALSE,
col = NULL,
xlab = "State",
ylab = "Person-specific median",
title = NULL,
range = c(0, 25),
hjust = 0.5,
lineheight = 1.2,
cex.lab = 1.5,
cex.main = 1.5,
legend.width = 2.4,
legend.mar = 6.1,
lwd = 1.5,
...
)
x |
A model object of class |
type |
the type of model output to plot: either |
bubble |
Logical: a bubble plot if |
col |
The colors for the range of the fitted values. |
xlab, ylab |
x- and y-axis labels. |
title |
Plot title. |
range |
Numeric vector of length 2 specifying the minimum and maximum size of the bubbles, if |
hjust |
Horizontal justification (in [0,1]). |
lineheight |
Line height. |
cex.lab |
Magnification for x and y labels. |
cex.main |
Magnification for main title. |
legend.width |
Width in characters of the legend. Default is 2.4. |
legend.mar |
Width in characters of legend margin that hasthe axis. Default is 6.1. |
lwd |
Line width of bordering lines around pixels. Default is 1.5 |
... |
Other graphical parameters. |
None; a plot is created.
This function assumes the store object includes the underlying data
(save.data==TRUE, the default in store).
Prince P. Osei and Philip T. Reiss
Osei, P. P. and Reiss, P. T. (2022). Ordinal state-trait regression for intensive longitudinal data. Under revision.
store
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.